(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 8.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc.                                               *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       835,         17]
NotebookDataLength[      9194,        242]
NotebookOptionsPosition[      9247,        226]
NotebookOutlinePosition[      9611,        242]
CellTagsIndexPosition[      9568,        239]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Sinc Function for Fermi\[CloseCurlyQuote]s Golden Rule\
\>", "Section",
 CellChangeTimes->{{3.544181178551051*^9, 3.5441811813434563`*^9}, {
  3.544181625596672*^9, 3.544181632959885*^9}},
 FontColor->RGBColor[0.5019607843137255, 0., 0.]],

Cell[CellGroupData[{

Cell[TextData[{
 "This function was introduced when deriving the Fermi\[CloseCurlyQuote]s \
Golden Rule. Here I plot:  [Sin(\[CapitalDelta]\[Omega] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"t", "/", "2"}], ")"}], "/", "\[CapitalDelta]\[Omega]"}], 
     "]"}], "2"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". \[LineSeparator]As the time increases, the function is more peaked around \
the origin."
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5441811898298707`*^9, 3.544181265131203*^9}, {
   3.5441829265453577`*^9, 3.544182930897765*^9}, 3.544182965202225*^9},
 FontFamily->"Arial Rounded MT Bold",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"SincPlot", "=", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"Dw", " ", 
           RowBox[{"t", "/", "2"}]}], "]"}], "^", "2"}], "/", 
        RowBox[{"Dw", "^", "2"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"Dw", ",", 
         RowBox[{
          RowBox[{"-", "4"}], "\[Pi]"}], ",", 
         RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "r"}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Inset", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Column", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<Peak height: \>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"N", "[", 
                  RowBox[{"Round", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"t", "^", "2"}], "/", "4"}], ",", "0.01"}], "]"}],
                   "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
               RowBox[{"\"\<Peak width: \>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"N", "[", 
                  RowBox[{"Round", "[", 
                   RowBox[{
                    RowBox[{"2", "/", "t"}], ",", "0.01"}], "]"}], "]"}], 
                 "]"}], "<>", "\"\<\[Times] \[Pi]\>\""}]}], "}"}], "]"}], ",",
             "14", ",", 
            RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], ",", "Bold"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.5"}], ",", 
            RowBox[{"r", ".8"}]}], "}"}]}], "]"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"600", ",", "300"}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[CapitalDelta]\[Omega]\>\"", ",", "\"\<\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "2", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Time\>\"", ",", "14", ",", 
           RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], ",", "Bold"}], 
          "]"}]}], "}"}], ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Verical plot range\>\"", ",", "14", ",", 
           RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], ",", "Bold"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"1", "/", "4"}], "\[IndentingNewLine]", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5441829490093966`*^9, 3.544182965202225*^9}, {
  3.544183023873928*^9, 3.5441830405815573`*^9}, {3.544183137426528*^9, 
  3.5441831386121297`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["SincPlot"], "Input",
 CellChangeTimes->{{3.5441812675336075`*^9, 3.5441814116154604`*^9}, {
  3.5441815050084605`*^9, 3.544181579670192*^9}, {3.5441816556423254`*^9, 
  3.544181730865657*^9}, {3.544181769460125*^9, 3.544181842795854*^9}, {
  3.5441819030275593`*^9, 3.5441819290328054`*^9}, {3.5441819672840724`*^9, 
  3.5441819692184763`*^9}, {3.5441821636260176`*^9, 3.5441824039288397`*^9}, {
  3.5441824356124954`*^9, 3.544182438872901*^9}, {3.5441824813361754`*^9, 
  3.5441827505926485`*^9}, {3.544182796409929*^9, 3.5441828686068554`*^9}, {
  3.5441829451093903`*^9, 3.54418297371984*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{NMR`getPO`r$$ = 2 Pi, NMR`MatOp`t$$ = 4., 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[NMR`MatOp`t$$], 2, 
       Style["Time", 14, FontFamily -> "Helvetica", Bold]}, 1, 5}, {{
       Hold[NMR`getPO`r$$], 2 Pi, 
       Style["Verical plot range", 14, FontFamily -> "Helvetica", Bold]}, 
      Rational[1, 4], 2 Pi}}, Typeset`size$$ = {600., {148., 152.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True, 
    NMR`MatOp`t$605$$ = 0, NMR`getPO`r$606$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {NMR`getPO`r$$ = 2 Pi, NMR`MatOp`t$$ = 2}, 
      "ControllerVariables" :> {
        Hold[NMR`MatOp`t$$, NMR`MatOp`t$605$$, 0], 
        Hold[NMR`getPO`r$$, NMR`getPO`r$606$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[Sin[$CellContext`Dw (NMR`MatOp`t$$/
            2)]^2/$CellContext`Dw^2, {$CellContext`Dw, (-4) Pi, 4 Pi}, 
        PlotRange -> {0, NMR`getPO`r$$}, PlotStyle -> {Black, Thick}, Epilog -> 
        Inset[
          Style[
           Column[{
             StringJoin["Peak height: ", 
              ToString[
               N[
                Round[NMR`MatOp`t$$^2/4, 0.01]]]], "", 
             StringJoin["Peak width: ", 
              ToString[
               N[
                Round[2/NMR`MatOp`t$$, 0.01]]], "\[Times] \[Pi]"]}], 14, 
           FontFamily -> "Helvetica", Bold], {-9.5, NMR`getPO`r$$ 0.8}], 
        ImageSize -> {600, 300}, AspectRatio -> 0.5, 
        AxesLabel -> {"\[CapitalDelta]\[Omega]", ""}], 
      "Specifications" :> {{{NMR`MatOp`t$$, 2, 
          Style["Time", 14, FontFamily -> "Helvetica", Bold]}, 1, 5}, {{
         NMR`getPO`r$$, 2 Pi, 
          Style["Verical plot range", 14, FontFamily -> "Helvetica", Bold]}, 
         Rational[1, 4], 2 Pi}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{645., {206., 211.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.544182362869567*^9, 3.5441823972364273`*^9}, 
   3.544182439606102*^9, {3.5441824832237787`*^9, 3.54418250673302*^9}, {
   3.544182542613083*^9, 3.544182737161025*^9}, {3.544182798515932*^9, 
   3.544182827875184*^9}, {3.544182860182841*^9, 3.544182869308857*^9}, 
   3.5441829743750415`*^9, 3.5441830434519625`*^9, 3.544183140998934*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{931, 602},
WindowMargins->{{18, Automatic}, {Automatic, 23}},
ShowSelection->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1257, 32, 248, 5, 71, "Section"],
Cell[CellGroupData[{
Cell[1530, 41, 735, 19, 53, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2268, 62, 3277, 84, 172, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[5582, 151, 610, 8, 25, "Input"],
Cell[6195, 161, 3024, 61, 434, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 4xpMeyqz3G2K9AKEtifBzPfz *)
